==> ZenTaoPMS.max2.4.php7.0.zip: zentaopms/module/upgrade/ext/config/zentaomax.php <==
<?php
$config->maxVersion = array();
$config->maxVersion['max2_0_rc1']   = '15_0_rc3';
$config->maxVersion['max2_0']       = '15_0';
$config->maxVersion['max2_1']       = '15_3';
$config->maxVersion['max2_2']       = '15_5';
$config->maxVersion['max2_3']       = '15_7';
$config->maxVersion['max2_3_1']     = '15_7_1';
$config->maxVersion['max2_4_beta1'] = '16_0_beta1';
$config->maxVersion['max2_4']       = '16_0';

$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello2.start.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test2.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/index.html';
$config->delete['20.0.beta3'][] = 'module/action/ext/model/hook/create.xuanxuan.php';

$config->delete['2.0.rc1'][]   = 'module/bug/ext/model/zentaomax.php';
$config->delete['2.0.rc1'][]   = 'module/doc/ext/view/browse.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/action/ext/model/class/search.class.php';
$config->delete['2.0.rc1'][]   = 'module/action/ext/model/search.php';
$config->delete['2.0.rc1'][]   = 'module/product/ext/model/web.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/calendar.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/effort.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/gantt.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/view.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/taskeffort.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/task.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/task.excel.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/requirement.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/relation.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/managemembers.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/maintainrelation.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/kanban.word.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/gantt.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/finish.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.gantt.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.calendar.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effortcalendar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effort.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effort.calendar.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/edit.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/calendar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/ajaxkanbansetting.flow.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/search/ext/model/search.php';
$config->delete['2.0.rc1'][]   = 'module/story/ext/model/class/bizext.class.php';
$config->delete['2.0.rc1'][]   = 'module/story/ext/model/bizext.php';
$config->delete['2.0.rc1'][]   = 'module/dept/ext/model/getlistbytype.php';
$config->delete['2.0.rc1'][]   = 'module/block/ext/lang/zh-cn/cmmi.php';
$config->delete['2.0'][]       = 'module/group/ext/lang/zh-cn/zzcmmi.php';
$config->delete['2.0'][]       = 'module/group/ext/lang/en/zzcmmi.php';
$config->delete['2.0'][]       = 'module/project/ext/lang/zh-cn/cmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/zh-cn/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/zh-tw/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/en/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/batchedit.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/create.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/edit.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/batchedit.html.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/create.html.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/edit.html.php';
$config->delete['2.4.beta1'][] = 'module/product/css/create.css';
$config->delete['2.4.beta1'][] = 'module/project/ext/model/class/zentaomax.class.php';
$config->delete['2.4.beta1'][] = 'module/project/ext/model/zentaomax.php';

$config->excludeFiles['module/story/ext/control/batchedit.php'] = 1;

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/upgrade/ext/config/zentaomax.php <==
<?php
$config->maxVersion = array();
$config->maxVersion['max2_0_rc1']   = '15_0_rc3';
$config->maxVersion['max2_0']       = '15_0';
$config->maxVersion['max2_1']       = '15_3';
$config->maxVersion['max2_2']       = '15_5';
$config->maxVersion['max2_3']       = '15_7';
$config->maxVersion['max2_3_1']     = '15_7_1';
$config->maxVersion['max2_4_beta1'] = '16_0_beta1';
$config->maxVersion['max2_4']       = '16_0';
$config->maxVersion['max2_5']       = '16_1';
$config->maxVersion['max2_6']       = '16_2';
$config->maxVersion['max2_7']       = '16_3';

$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello2.start.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test2.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/hello.test.php';
$config->delete['20.0.beta3'][] = 'module/misc/ext/model/hook/index.html';
$config->delete['20.0.beta3'][] = 'module/action/ext/model/hook/create.xuanxuan.php';

$config->delete['2.0.rc1'][]   = 'module/bug/ext/model/zentaomax.php';
$config->delete['2.0.rc1'][]   = 'module/doc/ext/view/browse.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/action/ext/model/class/search.class.php';
$config->delete['2.0.rc1'][]   = 'module/action/ext/model/search.php';
$config->delete['2.0.rc1'][]   = 'module/product/ext/model/web.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/calendar.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/effort.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/model/gantt.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/view.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/taskeffort.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/task.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/task.excel.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/requirement.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/relation.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/managemembers.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/maintainrelation.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/kanban.word.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/gantt.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/finish.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.gantt.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/featurebar.calendar.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effortcalendar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effort.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/effort.calendar.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/edit.cmmi.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/calendar.html.php';
$config->delete['2.0.rc1'][]   = 'module/project/ext/view/ajaxkanbansetting.flow.html.hook.php';
$config->delete['2.0.rc1'][]   = 'module/search/ext/model/search.php';
$config->delete['2.0.rc1'][]   = 'module/story/ext/model/class/bizext.class.php';
$config->delete['2.0.rc1'][]   = 'module/story/ext/model/bizext.php';
$config->delete['2.0.rc1'][]   = 'module/dept/ext/model/getlistbytype.php';
$config->delete['2.0.rc1'][]   = 'module/block/ext/lang/zh-cn/cmmi.php';
$config->delete['2.0'][]       = 'module/group/ext/lang/zh-cn/zzcmmi.php';
$config->delete['2.0'][]       = 'module/group/ext/lang/en/zzcmmi.php';
$config->delete['2.0'][]       = 'module/project/ext/lang/zh-cn/cmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/zh-cn/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/zh-tw/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/common/ext/lang/en/zzcmmi.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/batchedit.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/create.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/control/edit.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/batchedit.html.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/create.html.php';
$config->delete['2.4.beta1'][] = 'module/execution/ext/view/edit.html.php';
$config->delete['2.4.beta1'][] = 'module/product/css/create.css';
$config->delete['2.4.beta1'][] = 'module/project/ext/model/class/zentaomax.class.php';
$config->delete['2.4.beta1'][] = 'module/project/ext/model/zentaomax.php';

$config->excludeFiles['module/story/ext/control/batchedit.php'] = 1;
